builder

Function builder 

pub fn builder(path: &str, baud_rate: u32) -> SerialPortBuilder
Available on crate feature serial only.
Return a SerialPortBuilder preconfigured with the same defaults as open, but unopened, so the caller can apply further tweaks before calling .open().