DecodeError

Enum DecodeError 

pub enum DecodeError {
    Incomplete {
        need: usize,
        have: usize,
    },
    BadToken {
        expected: u16,
        got: u16,
    },
    HeaderChecksum {
        stored: u16,
        computed: u16,
    },
    PayloadChecksum {
        stored: u16,
        computed: u16,
    },
}
Reasons a decode call may fail.

Variants



Incomplete

Buffer ended before a complete packet could be read.

Fields

need: usize

Number of bytes the decoder needed to be present.

have: usize

Number of bytes actually available.



BadToken

Start token at offset 0 did not match PACKET_TOKEN.

Fields

expected: u16

The constant token expected.

got: u16

The token actually decoded.



HeaderChecksum

Recomputed Fletcher-16 over the header bytes did not match the stored value.

Fields

stored: u16

Checksum stored in the packet.

computed: u16

Checksum computed from the header bytes.



PayloadChecksum

Recomputed Fletcher-16 over the body bytes did not match the stored value.

Fields

stored: u16

Checksum stored after the payload.

computed: u16

Checksum computed from the body bytes.