Module common

Module common 

Available on (crate features blocking or tokio or serial) and (crate features blocking or tokio) only.
Shared types used by both the blocking and tokio adapter modules.

Living here rather than in either adapter module so that enabling one adapter doesn’t require enabling the other to resolve UploadOptions / UploadStats / UploadError symbols.

Structs

UploadOptions
Caller-supplied options controlling the upload.
UploadStats
Upload statistics returned on success.

Enums

UploadError
Errors the adapter upload helpers can produce.