pub enum DecodeError {
Incomplete {
need: usize,
have: usize,
},
BadToken {
expected: u16,
got: u16,
},
HeaderChecksum {
stored: u16,
computed: u16,
},
PayloadChecksum {
stored: u16,
computed: u16,
},
}Expand description
Reasons a decode call may fail.
Variants
Incomplete
Buffer ended before a complete packet could be read.
Fields
BadToken
Start token at offset 0 did not match PACKET_TOKEN.
HeaderChecksum
Recomputed Fletcher-16 over the header bytes did not match the stored value.
Fields
PayloadChecksum
Recomputed Fletcher-16 over the body bytes did not match the stored value.